@@ -3,6 +3,7 @@ use Any::Moose;
 use Any::Moose '::Util::TypeConstraints';
 use Net::Google::DataAPI::Auth::AuthSub;
 use Net::Google::AuthSub;
+use URI;
 
 role_type 'Net::Google::DataAPI::Types::Auth'
     => {role => 'Net::Google::DataAPI::Role::Auth'};
@@ -18,4 +19,11 @@ coerce 'Net::Google::DataAPI::Types::Auth'
         );
     };
 
+subtype 'Net::Google::DataAPI::Types::URI'
+    => as 'URI';
+
+coerce 'Net::Google::DataAPI::Types::URI'
+    => from 'Str'
+    => via { URI->new(( m{://} ) ? $_ : ('http://'.$_)) };
+
 1;
